@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-history.c,v 1.67 2006/12/17 03:06:12 bjornl Exp $
+ *  $Id: ephy-history.c 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "config.h"
@@ -29,6 +29,7 @@
 #include "ephy-node-common.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
+#include "ephy-glib-compat.h"
 
 #include <time.h>
 #include <string.h>
@@ -38,12 +39,15 @@
 #define EPHY_HISTORY_XML_ROOT	 (const xmlChar *)"ephy_history"
 #define EPHY_HISTORY_XML_VERSION (const xmlChar *)"1.0"
 
-/* how often to save the history, in milliseconds */
-#define HISTORY_SAVE_INTERVAL (5 * 60 * 1000)
+/* how often to save the history, in seconds */
+#define HISTORY_SAVE_INTERVAL (5 * 60)
 
 /* if you change this remember to change also the user interface description */
 #define HISTORY_PAGE_OBSOLETE_DAYS 10
 
+/* the number of seconds in a day */
+#define SECS_PER_DAY (60*60*24)
+
 #define EPHY_HISTORY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_HISTORY, EphyHistoryPrivate))
 
 struct _EphyHistoryPrivate
@@ -239,23 +243,13 @@ ephy_history_class_init (EphyHistoryClass *klass)
 }
 
 static gboolean
-page_is_obsolete (EphyNode *node, GDate *now)
+page_is_obsolete (EphyNode *node, time_t now)
 {
 	int last_visit;
-	GDate date;
 
 	last_visit = ephy_node_get_property_int
 		(node, EPHY_NODE_PAGE_PROP_LAST_VISIT);
-
-        g_date_clear (&date, 1);
-#if GLIB_CHECK_VERSION (2,9,0)
-        g_date_set_time_t (&date, last_visit);
-#else
-        g_date_set_time (&date, last_visit);
-#endif
-
-	return (g_date_days_between (&date, now) >=
-		HISTORY_PAGE_OBSOLETE_DAYS);
+	return now - last_visit >= HISTORY_PAGE_OBSOLETE_DAYS*SECS_PER_DAY;
 }
 
 static void
@@ -263,16 +257,9 @@ remove_obsolete_pages (EphyHistory *eb)
 {
 	GPtrArray *children;
 	int i;
-	GTime now;
-	GDate current_date;
+	time_t now;
 
 	now = time (NULL);
-        g_date_clear (&current_date, 1);
-#if GLIB_CHECK_VERSION (2,9,0)
-        g_date_set_time_t (&current_date, time (NULL));
-#else
-        g_date_set_time (&current_date, time (NULL));
-#endif
 
 	children = ephy_node_get_children (eb->priv->pages);
 	for (i = (int) children->len - 1; i >= 0; i--)
@@ -281,7 +268,7 @@ remove_obsolete_pages (EphyHistory *eb)
 
 		kid = g_ptr_array_index (children, i);
 
-		if (page_is_obsolete (kid, &current_date))
+		if (page_is_obsolete (kid, now))
 		{
 			ephy_node_unref (kid);
 		}
@@ -606,7 +593,7 @@ ephy_history_init (EphyHistory *eb)
 
 	/* setup the periodic history saving callback */
 	eb->priv->autosave_timeout =
-		g_timeout_add (HISTORY_SAVE_INTERVAL,
+		g_timeout_add_seconds (HISTORY_SAVE_INTERVAL,
 		       (GSourceFunc)periodic_save_cb,
 		       eb);
 
