@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: mozilla-embed-single.cpp 6971 2007-03-16 11:09:15Z hadess $
+ *  $Id: mozilla-embed-single.cpp 7208 2007-07-27 20:27:56Z xan $
  */
 
 #include "mozilla-config.h"
@@ -44,8 +44,6 @@
 #include <nsIFile.h>
 #include <nsIIOService.h>
 #include <nsILocalFile.h>
-#include <nsIPassword.h>
-#include <nsIPasswordManager.h>
 #include <nsIPermission.h>
 #include <nsIPermissionManager.h>
 #include <nsIPrefService.h>
@@ -69,6 +67,11 @@
 #include <nsNetCID.h>
 #endif /* ALLOW_PRIVATE_API */
 
+#ifndef HAVE_GECKO_1_9
+#include <nsIPassword.h>
+#include <nsIPasswordManager.h>
+#endif /* !HAVE_GECKO_1_9 */
+
 #include "ephy-file-helpers.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-certificate-manager.h"
@@ -134,94 +137,19 @@ static void mozilla_embed_single_init		(MozillaEmbedSingle *ges);
 static void ephy_certificate_manager_iface_init	(EphyCertificateManagerIface *iface);
 #endif
 
-static GObjectClass *parent_class = NULL;
-
-GType
-mozilla_embed_single_get_type (void)
-{
-       static GType type = 0;
-
-        if (G_UNLIKELY (type == 0))
-        {
-                const GTypeInfo our_info =
-                {
-                        sizeof (MozillaEmbedSingleClass),
-                        NULL, /* base_init */
-                        NULL, /* base_finalize */
-                        (GClassInitFunc) mozilla_embed_single_class_init,
-                        NULL, /* class_finalize */
-                        NULL, /* class_data */
-                        sizeof (MozillaEmbedSingle),
-                        0,    /* n_preallocs */
-                        (GInstanceInitFunc) mozilla_embed_single_init
-                };
-
-		const GInterfaceInfo embed_single_info =
-		{
-			(GInterfaceInitFunc) ephy_embed_single_iface_init,
-			NULL,
-			NULL
-		};
-
-		const GInterfaceInfo cookie_manager_info =
-		{
-			(GInterfaceInitFunc) ephy_cookie_manager_iface_init,
-			NULL,
-			NULL
-		};
-
-		const GInterfaceInfo password_manager_info =
-		{
-			(GInterfaceInitFunc) ephy_password_manager_iface_init,
-			NULL,
-			NULL
-		};
-
-		const GInterfaceInfo permission_manager_info =
-		{
-			(GInterfaceInitFunc) ephy_permission_manager_iface_init,
-			NULL,
-			NULL
-		};
-
+G_DEFINE_TYPE_WITH_CODE (MozillaEmbedSingle, mozilla_embed_single, G_TYPE_OBJECT,
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_EMBED_SINGLE,
+                                                ephy_embed_single_iface_init)
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_COOKIE_MANAGER,
+                                                ephy_cookie_manager_iface_init)
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_PASSWORD_MANAGER,
+                                                ephy_password_manager_iface_init)
 #ifdef ENABLE_CERTIFICATE_MANAGER
-		const GInterfaceInfo certificate_manager_info =
-		{
-			(GInterfaceInitFunc) ephy_certificate_manager_iface_init,
-			NULL,
-			NULL
-		};
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_CERTIFICATE_MANAGER,
+                                                ephy_certificate_manager_iface_init)
 #endif
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "MozillaEmbedSingle",
-					       &our_info,
-					       (GTypeFlags)0);
-
-		g_type_add_interface_static (type,
-					     EPHY_TYPE_EMBED_SINGLE,
-					     &embed_single_info);
-
-		g_type_add_interface_static (type,
-					     EPHY_TYPE_COOKIE_MANAGER,
-					     &cookie_manager_info);
-
-		g_type_add_interface_static (type,
-					     EPHY_TYPE_PASSWORD_MANAGER,
-					     &password_manager_info);
-
-		g_type_add_interface_static (type,
-					     EPHY_TYPE_PERMISSION_MANAGER,
-					     &permission_manager_info);
-#ifdef ENABLE_CERTIFICATE_MANAGER
-		g_type_add_interface_static (type,
-					     EPHY_TYPE_CERTIFICATE_MANAGER,
-					     &certificate_manager_info);
-#endif
-	}
-
-        return type;
-}
+                         G_IMPLEMENT_INTERFACE (EPHY_TYPE_PERMISSION_MANAGER,
+                                                ephy_permission_manager_iface_init))
 
 static gboolean
 mozilla_set_default_prefs (MozillaEmbedSingle *mes)
@@ -638,6 +566,9 @@ impl_init (EphyEmbedSingle *esingle)
 {
 	MozillaEmbedSingle *single = MOZILLA_EMBED_SINGLE (esingle);
 
+	g_setenv ("MOZILLA_POSTSCRIPT_ENABLED", "1", TRUE);
+	g_unsetenv ("MOZILLA_POSTSCRIPT_PRINTER_LIST");
+
 #ifdef MOZ_ENABLE_XPRINT
 	/* XPrint? No, thanks! */
 	g_unsetenv ("XPSERVERLIST");
@@ -733,7 +664,7 @@ mozilla_embed_single_dispose (GObject *object)
 		priv->mSingleObserver = nsnull;
 	}
 
-	parent_class->dispose (object);
+	G_OBJECT_CLASS (mozilla_embed_single_parent_class)->dispose (object);
 }
 
 static void
@@ -743,7 +674,7 @@ mozilla_embed_single_finalize (GObject *object)
 
 	/* Destroy EphyEmbedSingle before because some
 	 * services depend on xpcom */
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (mozilla_embed_single_parent_class)->finalize (object);
 
 	mozilla_notifiers_shutdown ();
 
@@ -930,6 +861,7 @@ impl_list_passwords (EphyPasswordManager *manager)
 {
 	GList *passwords = NULL;
 
+#ifndef HAVE_GECKO_1_9
 	nsresult rv;
 	nsCOMPtr<nsIPasswordManager> passwordManager =
 			do_GetService (NS_PASSWORDMANAGER_CONTRACTID);
@@ -982,6 +914,7 @@ impl_list_passwords (EphyPasswordManager *manager)
 
 		passwords = g_list_prepend (passwords, p);
 	}
+#endif /* !HAVE_GECKO_1_9 */
 
 	return passwords;
 }
@@ -990,6 +923,7 @@ static void
 impl_remove_password (EphyPasswordManager *manager,
 		      EphyPasswordInfo *info)
 {
+#ifndef HAVE_GECKO_1_9
         nsCOMPtr<nsIPasswordManager> pm =
                         do_GetService (NS_PASSWORDMANAGER_CONTRACTID);
 	if (!pm) return;
@@ -1007,13 +941,15 @@ impl_remove_password (EphyPasswordManager *manager,
 	NS_CStringToUTF16 (nsCString(info->username),
 			   NS_CSTRING_ENCODING_UTF8, userName);
 	pm->RemoveUser (host, userName);
+#endif /* !HAVE_GECKO_1_9 */
 }
 
 static void
 impl_add_password (EphyPasswordManager *manager,
                   EphyPasswordInfo *info)
 {
-        nsCOMPtr<nsIPasswordManager> pm =
+#ifndef HAVE_GECKO_1_9
+       nsCOMPtr<nsIPasswordManager> pm =
                         do_GetService (NS_PASSWORDMANAGER_CONTRACTID);
        if (!pm) return;
 
@@ -1035,6 +971,7 @@ impl_add_password (EphyPasswordManager *manager,
                           NS_CSTRING_ENCODING_UTF8, password);
 
        pm->AddUser(host, username, password);
+#endif /* !HAVE_GECKO_1_9 */
 }
 
 static void
@@ -1351,8 +1288,6 @@ mozilla_embed_single_class_init (MozillaEmbedSingleClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
-
 	object_class->dispose = mozilla_embed_single_dispose;
 	object_class->finalize = mozilla_embed_single_finalize;
 	object_class->get_property = mozilla_embed_single_get_property;
