@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-helpers.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-file-helpers.c 7146 2007-07-10 22:15:04Z chpe $
  */
 
 #include "config.h"
@@ -102,8 +102,13 @@ char *
 ephy_file_downloads_dir (void)
 {
 	const char *translated_folder;
+	const char *xdg_download_dir;
 	char *desktop_dir, *converted, *downloads_dir;
 
+	xdg_download_dir = g_get_user_special_dir (G_USER_DIRECTORY_DOWNLOAD);
+	if (xdg_download_dir != NULL)
+		return g_strdup (xdg_download_dir);
+
 	/* The name of the default downloads folder */
 	translated_folder = _("Downloads");
 
@@ -164,22 +169,14 @@ ephy_file_get_downloads_dir (void)
 char *
 ephy_file_desktop_dir (void)
 {
+	const char *xdg_desktop_dir;
 	char *downloads_dir;
-	gboolean desktop_is_home;
 
-	desktop_is_home = eel_gconf_get_boolean (CONF_DESKTOP_IS_HOME_DIR);
+	xdg_desktop_dir = g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP);
+	if (xdg_desktop_dir != NULL)
+		return g_strdup (xdg_desktop_dir);
 
-	if (desktop_is_home)
-	{
-		downloads_dir = g_strdup (g_get_home_dir ()); 
-	}
-	else
-	{
-		downloads_dir = g_build_filename
-			(g_get_home_dir (), "Desktop", NULL);
-	}
-
-	return downloads_dir;
+	return g_build_filename	(g_get_home_dir (), "Desktop", NULL);
 }
 
 char *
@@ -1019,19 +1016,33 @@ gboolean
 ephy_file_browse_to (const char *parameter,
 		     guint32 user_time)
 {
-	GnomeVFSURI *uri, *parent_uri;
+	GnomeVFSURI *uri, *parent_uri, *desktop;
+	char *desktop_dir;
 	gboolean ret;
 
 	uri = gnome_vfs_uri_new (parameter);
 	parent_uri = gnome_vfs_uri_get_parent (uri);
 
-	/* TODO find a way to make nautilus scroll to the actual file */
-	ret = ephy_file_launch_handler ("x-directory/normal", 
-					gnome_vfs_uri_get_path (parent_uri), 
-					user_time);
+	desktop_dir = ephy_file_desktop_dir ();
+	desktop = gnome_vfs_uri_new (desktop_dir);
 	
+	/* Don't do anything if destination is the desktop */
+	if (gnome_vfs_uri_equal (desktop, parent_uri))
+	{
+		ret = FALSE;
+	}
+	else
+	{
+		/* TODO find a way to make nautilus scroll to the actual file */
+		ret = ephy_file_launch_handler ("x-directory/normal", 
+						gnome_vfs_uri_get_path (parent_uri), 
+						user_time);
+	}
+	
+	g_free (desktop_dir);
 	gnome_vfs_uri_unref (uri);
 	gnome_vfs_uri_unref (parent_uri);
+	gnome_vfs_uri_unref (desktop);
 
 	return ret;
 }
