@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-stock-icons.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: ephy-stock-icons.c 7191 2007-07-21 13:36:40Z wbolster $
  */
 
 #include "config.h"
@@ -37,16 +37,14 @@ ephy_stock_icons_init (void)
 	GtkIconSource *icon_source;
 	int i;
 
-	static const char *icon_theme_items[] =
+	const char *icon_theme_items[] =
 	{
 		STOCK_NEW_TAB,
 		STOCK_NEW_WINDOW,
 		STOCK_SEND_MAIL,
+		STOCK_NEW_MAIL,
 		STOCK_ADD_BOOKMARK,
 		STOCK_PRINT_SETUP,
-		STOCK_LOCK_INSECURE,
-		STOCK_LOCK_SECURE,
-		STOCK_LOCK_BROKEN,
 	};
 
 	static const GtkStockItem items[] =
@@ -56,7 +54,10 @@ ephy_stock_icons_init (void)
 		{ EPHY_STOCK_BOOKMARK,  N_("Bookmark"),         0, 0, NULL },
 		{ EPHY_STOCK_BOOKMARKS, N_("Bookmarks"),	0, 0, NULL },
 		{ EPHY_STOCK_ENTRY,	N_("Address Entry"),	0, 0, NULL },
-		{ EPHY_STOCK_DOWNLOAD,	N_("_Download"),	0, 0, NULL }
+		{ STOCK_DOWNLOAD,	N_("_Download"),	0, 0, NULL },
+		{ STOCK_LOCK_INSECURE },
+		{ STOCK_LOCK_SECURE },
+		{ STOCK_LOCK_BROKEN }
 	};
 
 	factory = gtk_icon_factory_new ();
